==> splight_lib-2.3.0-py3-none-any.whl: splight_lib/logging/_internal.py <==
import os
from typing import Optional
from logging import Formatter, Handler, INFO
from splight_lib.logging.logging import (
    SplightFormatter,
    SplightLogger,
    standard_output_handler,
)
from concurrent_log_handler import ConcurrentRotatingFileHandler
from enum import auto
from strenum import UppercaseStrEnum


class LogTags(UppercaseStrEnum):
    RUNTIME = auto()
    BINDING = auto()
    COMMUNICATION = auto()
    INDEX = auto()
    SECRET = auto()
    HOOK = auto()
    SETPOINT = auto()
    COMMAND = auto()
    PARAMETER = auto()
    COMPONENT = auto()  # TODO: not used yet.
    DATABASE = auto()
    DATALAKE = auto()
    CACHE = auto()


# don't used now
def splight_dev_file_handler(
    formatter: Optional[Formatter] = SplightFormatter(),
    log_level: Optional[str] = INFO,
) -> Handler:
    filename = os.getenv("SPLIGHT_DEVELOPER_LOG_FILE", "/tmp/splight-dev.log")
    max_bytes = int(os.getenv("SPLIGHT_DEVELOPER_MAX_BYTES", 5e6))  # 5MB
    backup_count = int(os.getenv("SPLIGHT_DEVELOPER_BACKUP_COUNT", 100))

    handler = ConcurrentRotatingFileHandler(
        filename=filename, maxBytes=max_bytes, backupCount=backup_count
    )
    handler.setFormatter(formatter)
    handler.setLevel(log_level)
    return handler


def get_splight_logger(name: Optional[str] = None):
    """Stdout logger."""
    if name is None:
        name = "splight-dev"
    logger = SplightLogger(name=name)
    logger.propagate = False
    handler = standard_output_handler(log_level=logger.level)
    logger.addHandler(handler)

    # Add logger.level to root logger
    logger.setLevel(logger.level)
    return logger

==> splight_lib-3.1.1-py3-none-any.whl: splight_lib/logging/_internal.py <==
import os
from enum import auto
from logging import INFO, Formatter, Handler
from typing import Optional

from concurrent_log_handler import ConcurrentRotatingFileHandler
from splight_lib.logging.logging import (
    SplightFormatter,
    SplightLogger,
    standard_output_handler,
)
from strenum import UppercaseStrEnum


# TODO: add more tags
class LogTags(UppercaseStrEnum):
    RUNTIME = auto()
    BINDING = auto()
    COMMUNICATION = auto()
    INDEX = auto()
    SECRET = auto()
    HOOK = auto()
    SETPOINT = auto()
    COMMAND = auto()
    PARAMETER = auto()
    COMPONENT = auto()
    DATABASE = auto()
    DATALAKE = auto()
    CACHE = auto()


# don't used now
def splight_dev_file_handler(
    formatter: Optional[Formatter] = SplightFormatter(),
    log_level: Optional[str] = INFO,
) -> Handler:
    filename = os.getenv("SPLIGHT_DEVELOPER_LOG_FILE", "/tmp/splight-dev.log")
    max_bytes = int(os.getenv("SPLIGHT_DEVELOPER_MAX_BYTES", 5e6))  # 5MB
    backup_count = int(os.getenv("SPLIGHT_DEVELOPER_BACKUP_COUNT", 100))

    handler = ConcurrentRotatingFileHandler(
        filename=filename, maxBytes=max_bytes, backupCount=backup_count
    )
    handler.setFormatter(formatter)
    handler.setLevel(log_level)
    return handler


def get_splight_logger(name: Optional[str] = None):
    """Stdout logger."""
    if name is None:
        name = "splight-dev"
    logger = SplightLogger(name=name)
    logger.propagate = False
    stdout_handler = standard_output_handler(log_level=logger.level)
    logger.addHandler(stdout_handler)
    logger.setLevel(logger.level)
    return logger
